@@ -335,7 +335,7 @@ public class CloudnResourceManagement_VPC extends CloudnResourceManagementBase {
 		}
 	}
 	
-	protected DeployVirtualMachineRequest getCreateInstanceRequest(String name, String flavor, String imageId, String zone, String instanceDetail, List<Tag> tags) throws CloudManagerFault, JsonProcessingException, IOException{
+	protected DeployVirtualMachineRequest getCreateInstanceRequest(String id, String name, String flavor, String imageId, String zone, String instanceDetail, List<Tag> tags) throws CloudManagerFault, JsonProcessingException, IOException{
 		ObjectMapper om = new ObjectMapper();
 		ObjectReader or = om.reader(InstanceDetail.class);
 		InstanceDetail detail = or.readValue(instanceDetail);
@@ -345,23 +345,23 @@ public class CloudnResourceManagement_VPC extends CloudnResourceManagementBase {
 		deployRequest.templateid = parseImageId(imageId).get(0, String.class); // 必須
 		deployRequest.zoneid = getZoneInternal(zone).id; // 必須
 //		request.diskofferingid = getStorageFlavorName(detail.);
-		deployRequest.displayname = name;
+		deployRequest.displayname = id;
 		deployRequest.group = detail.group;
 //		deployRequest.name = name + '-' + new Date().getTime();
 		String s = "";
-		for (String id: detail.networkIds) {
+		for (String networkId: detail.networkIds) {
 			if (!s.isEmpty()) s += ',';
-			s += id;
+			s += networkId;
 		}
 		deployRequest.networkids = s; // 必須
 		
 		return deployRequest;
 	}
 	
-	protected InstanceInfo internalCreateInstance(String name, String flavor, String imageId, String zone, String instanceDetail, List<Tag> tags) throws CloudManagerFault {
+	protected InstanceInfo internalCreateInstance(String id, String name, String flavor, String imageId, String zone, String instanceDetail, List<Tag> tags) throws CloudManagerFault {
 		CloudnCompute compute = getCloudnEndpoint();
 		try {
-			DeployVirtualMachineRequest deployRequest = getCreateInstanceRequest(name, flavor, imageId, zone, instanceDetail, tags);
+			DeployVirtualMachineRequest deployRequest = getCreateInstanceRequest(id, name, flavor, imageId, zone, instanceDetail, tags);
 			
 			DeployVirtualMachineResponse resoponse = compute.deployVirtualMachine(deployRequest);
 			ListVirtualMachinesResponse vmlist = compute.listVirtualMachines(new ListVirtualMachinesRequest().withId(resoponse.id));
@@ -437,8 +437,8 @@ public class CloudnResourceManagement_VPC extends CloudnResourceManagementBase {
 	}
 	
 	@Override
-	public Instance createInstance(String name, String flavor, String imageId, String zone, String instanceDetail, List<Tag> tags) throws CloudManagerFault {
-		return internalCreateInstance(name, flavor, imageId, zone, instanceDetail, tags).instance;
+	public Instance createInstance(String id, String name, String flavor, String imageId, String zone, String instanceDetail, List<Tag> tags) throws CloudManagerFault {
+		return internalCreateInstance(id, name, flavor, imageId, zone, instanceDetail, tags).instance;
 	}
 
 	@Override
@@ -1315,7 +1315,7 @@ public class CloudnResourceManagement_VPC extends CloudnResourceManagementBase {
 		return images.get(0);
 	}
 
-	protected RestoreInfo internalRestoreInstance(String instanceBackupId, String name, String flavor, String zone/*この情報は未使用。*/, String instanceDetail, List<Tag> tags) throws CloudManagerFault, JsonProcessingException, IOException{
+	protected RestoreInfo internalRestoreInstance(String facilityId, String instanceBackupId, String name, String flavor, String zone/*この情報は未使用。*/, String instanceDetail, List<Tag> tags) throws CloudManagerFault, JsonProcessingException, IOException{
 		String value = getStore().get(RT_InstanceBackup, instanceBackupId);
 
 		ObjectMapper om = new ObjectMapper();
@@ -1357,7 +1357,7 @@ public class CloudnResourceManagement_VPC extends CloudnResourceManagementBase {
 		}
 		String backupedDetail = om.writerWithType(InstanceDetail.class).writeValueAsString(backuped.instanceDetail);
 
-		return new RestoreInfo(internalCreateInstance(backuped.name, backuped.flavor, instanceBackupId, backuped.zone, backupedDetail, backuped.tags), backuped.attachedStorages, backuped.instanceDetail.attachingDisk);
+		return new RestoreInfo(internalCreateInstance(facilityId, backuped.name, backuped.flavor, instanceBackupId, backuped.zone, backupedDetail, backuped.tags), backuped.attachedStorages, backuped.instanceDetail.attachingDisk);
 	}
 	
 	protected static class RestoreInfo{
@@ -1375,9 +1375,9 @@ public class CloudnResourceManagement_VPC extends CloudnResourceManagementBase {
 	}
 	
 	@Override
-	public Instance restoreInstance(String instanceBackupId, String name, String flavor, String zone/*この情報は未使用。*/, String instanceDetail, List<Tag> tags) throws CloudManagerFault {
+	public Instance restoreInstance(String facilityId, String instanceBackupId, String name, String flavor, String zone/*この情報は未使用。*/, String instanceDetail, List<Tag> tags) throws CloudManagerFault {
 		try {
-			RestoreInfo restoreInfo = internalRestoreInstance(instanceBackupId, name, flavor, zone, instanceDetail, tags);
+			RestoreInfo restoreInfo = internalRestoreInstance(facilityId, instanceBackupId, name, flavor, zone, instanceDetail, tags);
 			final InstanceInfo instanceInfo = restoreInfo.instanceInfo;
 			SessionService.current().addRollbackAction(
 				new SessionService.RolebackAction() {
